@@ -31,7 +31,7 @@
 #define ITEM_WIDTH  10  /* The item's default size */
 #define ITEM_HEIGHT 10
 #ifndef RGB_TXT
-#define RGB_TXT     "/etc/X11/rgb.txt"
+#define RGB_TXT     "/usr/share/X11/rgb.txt"
 #endif
 
 /* put_pixmap - Draws the item's pixmap to the specified location */
@@ -98,7 +98,7 @@ int y_vel;
     item->display = static_data->display;
     item->window  = static_data->window;
 
-    /* Draw with the next avaliable pixmap image (color) */
+    /* Draw with the next available pixmap image (color) */
     static_data->curr_pixmap = 
         (static_data->curr_pixmap + 1) % static_data->num_colors;
 
